var group__new__in__4__10 =
[
    [ "ITextEditListener", "class_v_s_t_g_u_i_1_1_i_text_edit_listener.html", [
      [ "onTextEditPlatformControlLostFocus", "class_v_s_t_g_u_i_1_1_i_text_edit_listener.html#ae29ea68b734e08bbe137a375f7c0c8f2", null ],
      [ "onTextEditPlatformControlTookFocus", "class_v_s_t_g_u_i_1_1_i_text_edit_listener.html#af18b341ef0ac81ace658beefe52109ee", null ]
    ] ],
    [ "VSTGUI::exit", "group__new__in__4__10.html#ga358d2e2397ca11ccd17553e3c40e7901", null ],
    [ "VSTGUI::init", "group__new__in__4__10.html#gacb669fbf9e184809ae58b5cfa4741088", null ],
    [ "VSTGUI::IOptionMenuListener::onOptionMenuSetPopupResult", "group__new__in__4__10.html#ga62e791b9e7fba05bf64b8634ecc30a17", null ]
];